<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package Catch Themes
 * @subpackage Adventurous
 * @since Adventurous 1.0
 */

if ( ! function_exists( 'adventurous_register_styles' ) ) :
/**
 * Register theme styles
 *
 * Registers stylesheets used by the theme.
 * Also offers integration with Google Web Fonts Directory
 * @uses wp_register_style() To register styles
 *
 * @since Adventurous 1.0.
 */
function adventurous_register_styles() {
	//Getting Ready to load data from Theme Options Panel
	$options = adventurous_get_options();

	$fonts = array();
	$fonts[] = $options['body_font'];
	$fonts[] = $options['title_font'];
	$fonts[] = $options['tagline_font'];
	$fonts[] = $options['content_tittle_font'];
	$fonts[] = $options['content_font'];
	$fonts[] = $options['headings_font'];

	$web_fonts = array(
		'allan'					=> 'Allan',
		'allerta'				=> 'Allerta',
		'amaranth'				=> 'Amaranth',
		'bitter'				=> 'Bitter',
		'cabin'					=> 'Cabin',
		'cantarell'				=> 'Cantarell',
		'crimson-text'			=> 'Crimson+Text',
		'cuprum'				=> 'Cuprum',
		'dancing-script'		=> 'Dancing+Script',
		'droid-sans'			=> 'Droid+Sans',
		'droid-serif'			=> 'Droid+Serif',
		'istok-web'				=> 'Istok+Web',
		'lato'					=> 'Lato',
		'lobster'				=> 'Lobster',
		'lora'					=> 'Lora',
		'nobile'				=> 'Nobile',
		'open-sans'				=> 'Open+Sans',
		'oswald'				=> 'Oswald',
		'patua-one'				=> 'Patua+One',
		'playfair-display'		=> 'Playfair+Display',
		'pt-sans'				=> 'PT+Sans',
		'pt-serif'				=> 'PT+Serif',
		'quattrocento-sans' 	=> 'Quattrocento+Sans',
		'roboto'				=> 'Roboto',
		'ubuntu'				=> 'Ubuntu',
		'yanone-kaffeesatz' 	=> 'Yanone+Kaffeesatz'
	);

	$fonts = array_unique( $fonts ); // Make the array of fonts unique so that same font is not loaded twice
	$fonts = array_intersect( $fonts, array_keys( $web_fonts ) ); // Intersect selected fonts and webfonts to only recover fonts that need loading

	if ( !empty( $fonts ) ) {

		$web_fonts_stylesheet = '//fonts.googleapis.com/css?family=';

		$i	=	0;
		foreach( $fonts as $font ) {
			if ( $i )// only set | to $web_fonts_stylesheet from second loop onwards
				$web_fonts_stylesheet .='%7c';

			$web_fonts_stylesheet .= $web_fonts[ $font ] . ':300,300italic,regular,italic,600,600italic';

			$i = 1;
		}

		$web_fonts_stylesheet .= '&subset=latin';

	}
	else {
		$web_fonts_stylesheet = false;
	}

	if ( false !== $web_fonts_stylesheet ) {
		wp_register_style( 'adventurous-web-font', $web_fonts_stylesheet, false, null );
		$adventurous_deps = array( 'adventurous-web-font' );
	}
	else {
		$adventurous_deps = false;
	}

	wp_register_style( 'adventurous-pro', get_stylesheet_uri(), $adventurous_deps, null );

}
endif;
add_action( 'wp_enqueue_scripts', 'adventurous_register_styles' );


/**
 * Enqueue scripts and styles
 */
function adventurous_scripts() {
	global $wp_query;
	$options = adventurous_get_options();

	// Front page displays in Reading Settings
	$page_for_posts = get_option('page_for_posts');

	// Get Page ID outside Loop
	$page_id = $wp_query->get_queried_object_id();

	/**
	 * Loads up main stylesheet.
	 */
	wp_enqueue_style( 'adventurous-pro' );

	// Add Genericons font, used in the main stylesheet.
	wp_enqueue_style( 'genericons', get_template_directory_uri() . '/css/genericons/genericons.css', false, '3.4.1' );


	/**
	 * Loads up Color Scheme
	 */
	$color_scheme = $options['color_scheme'];
	if ( 'dark' == $color_scheme ) {
		wp_enqueue_style( 'dark', get_template_directory_uri() . '/css/dark.css', array(), null );
	}

	/**
	 * Loads up Responsive stylesheet and Menu JS
	 */
	if ( empty ($options['disable_responsive'] ) ) {
		wp_enqueue_style( 'adventurous-responsive', get_template_directory_uri() . '/css/responsive.css' );

		wp_enqueue_script( 'jquery-fitvids', get_template_directory_uri() . '/js/fitvids.min.js', array( 'jquery' ), '20140317', true );
	}

	/**
	 * Loads up jQuery Custom Scripts
	 */
	wp_enqueue_script( 'adventurous-custom', get_template_directory_uri() . '/js/adventurous-custom.min.js', array( 'jquery' ), '20150601', true );

	/**
	 * Adds JavaScript to pages with the comment form to support
	 * sites with threaded comments (when in use).
	 */
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if ( is_singular() && wp_attachment_is_image() ) {
		wp_enqueue_script( 'keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.min.js', array( 'jquery' ), '20120202' );
	}

	/**
	 * Register JQuery circle all and JQuery set up as dependent on Jquery-cycle
	 */
	wp_register_script( 'jquery-cycle', get_template_directory_uri() . '/js/jquery.cycle.all.min.js', array( 'jquery' ), '20140317', true );

	/**
	 * Loads up adventurous-slider and jquery-cycle set up as dependent on adventurous-slider
	 */
	$enableslider = $options['enable_slider'];

	if ( ( 'enable-slider-allpage' == $enableslider ) || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'enable-slider-homepage' == $enableslider ) ) {
		wp_enqueue_script( 'adventurous-slider', get_template_directory_uri() . '/js/adventurous-slider.min.js', array( 'jquery-cycle' ), '20140317', true );
	}

	// Load the html5 shiv.
	wp_enqueue_script( 'adventurous-html5', get_template_directory_uri() . '/js/html5.min.js', array(), '3.7.3' );
	wp_style_add_data( 'adventurous-html5', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'selectivizr', get_template_directory_uri() . '/js/selectivizr.min.js', array( 'jquery' ), '20130114', false );
	wp_style_add_data( 'selectivizr', 'conditional', 'lt IE 9' );

	wp_enqueue_style( 'adventurous-iecss', get_template_directory_uri() . '/css/ie.css' );
	wp_style_add_data( 'adventurous-iecss', 'conditional', 'lt IE 9' );

}
add_action( 'wp_enqueue_scripts', 'adventurous_scripts' );


/**
 * Responsive Layout
 *
 * @get the data value of responsive layout from theme options
 * @display responsive meta tag
 * @action wp_head
 */
function adventurous_responsive() {
	//delete_transient('adventurous_responsive');

	if ( !$adventurous_responsive = get_transient( 'adventurous_responsive' ) ) {
	$options = adventurous_get_options();

		if ( empty ($options['disable_responsive'] ) ) {
			$adventurous_responsive = '<meta name="viewport" content="width=device-width, initial-scale=1, minimum-scale=1">';
		}
		else {
			$adventurous_responsive = '<!-- Disable Responsive -->';
		}
		set_transient( 'adventurous_responsive', $adventurous_responsive, 86940 );
	}
	echo $adventurous_responsive;
} // adventurous_responsive
add_filter( 'wp_head', 'adventurous_responsive', 1 );


if ( ! function_exists( 'adventurous_content_image' ) ) :
/**
 * Template for Featured Image in Content
 *
 * To override this in a child theme
 * simply create your own adventurous_content_image(), and that function will be used instead.
 *
 * @since Adventurous 1.0
 */
function adventurous_content_image() {
	global $post, $wp_query;

	// Get Page ID outside Loop
	$page_id = $wp_query->get_queried_object_id();

	if ( $post) {
 		if ( is_attachment() ) {
			$parent = $post->post_parent;
			$individual_featured_image = get_post_meta( $parent,'adventurous-featured-image', true );
		} else {
			$individual_featured_image = get_post_meta( $page_id,'adventurous-featured-image', true );
		}
	}

	if ( empty( $individual_featured_image ) || ( !is_page() && !is_single() ) ) {
		$individual_featured_image='default';
	}

	// Getting data from Theme Options
	$options = adventurous_get_options();

	$featured_image = $options['featured_image'];

	if ( ( 'disable' == $individual_featured_image || '' == get_the_post_thumbnail() || ( $individual_featured_image=='default' && 'disable' == $featured_image) ) ) {
		return false;
	}
	else { ?>
		<figure class="featured-image">
            <a href="<?php the_permalink(); ?>" title="<?php echo esc_attr( sprintf( __( 'Permalink to %s', 'adventurous-pro' ), the_title_attribute( 'echo=0' ) ) ); ?>">
                <?php
				if ( ( is_front_page() && 'featured' == $featured_image ) ||  'featured' == $individual_featured_image || ( $individual_featured_image=='default' && 'featured' == $featured_image ) ) {
                     the_post_thumbnail( 'featured' );
                }
				elseif ( ( is_front_page() && 'slider' == $featured_image ) || 'slider' == $individual_featured_image || ( $individual_featured_image=='default' && 'slider' == $featured_image ) ) {
					the_post_thumbnail( 'slider' );
				}
				else {
					the_post_thumbnail( 'full' );
				} ?>
			</a>
        </figure>
   	<?php
	}
}
endif; //adventurous_content_image


/**
 * Hooks the Custom Inline CSS to head section
 *
 * @since Adventurous 1.0
 */
function adventurous_inline_css() {
	//delete_transient( 'adventurous_inline_css' );

	if ( ( !$adventurous_inline_css = get_transient( 'adventurous_inline_css' ) ) ) {
		// Getting data from Theme Options
		$options = adventurous_get_options();
		$defaults = adventurous_get_defaults();
		$fonts = adventurous_available_fonts();

		$adventurous_inline_css	= '';

		// Disable Responsive Design
		if ( !empty( $options['disable_responsive'] ) ) {
			$adventurous_inline_css	.=  "#masthead { position: fixed; top: 0; }". "\n";
			$adventurous_inline_css	.=  "#masthead, #secondary-menu, #main-slider, #header-featured-image, #homepage-message, #featured-post, #colophon { min-width: 1290px; min-width: 129rem; }". "\n";
			$adventurous_inline_css	.=  ".container { padding-right: 20px; padding-right: 2rem; padding-left: 20px; padding-left: 2rem; }". "\n";

		}

		//Color Options
		if ( $defaults[ 'header_background' ] != $options['header_background'] ) {
			$adventurous_inline_css	.= "#masthead { background-color: ".  $options['header_background'] ."; }". "\n";
		}
		if ( $defaults[ 'featured_background' ] != $options['featured_background'] ) {
			$adventurous_inline_css	.= "#featured-post { background-color: ".  $options['featured_background'] ."; }". "\n";
		}
		if ( $defaults[ 'content_background' ] != $options['content_background'] ) {
			$adventurous_inline_css	.= "#content article, #content .page-header, #comments, #content .author-info { background-color: ".  $options['content_background'] ."; }". "\n";
		}
		if ( $defaults[ 'title_color' ] != $options['title_color'] ) {
			$adventurous_inline_css	.=  ".page-header, #featured-heading h2, .entry-header .entry-title a, .entry-header .entry-title, #featured-post .entry-title { color: ".  $options['title_color'] ."; }". "\n";
		}
		if ( $defaults[ 'title_hover_color' ] != $options['title_hover_color'] ) {
			$adventurous_inline_css	.=  ".entry-header .entry-title a:hover { color: ".  $options['title_hover_color'] ."; }". "\n";
		}
		if ( $defaults[ 'text_color' ] != $options['text_color'] ) {
			$adventurous_inline_css	.=  "body, button, input, select, textarea { color: ".  $options['text_color'] ."; }". "\n";
		}
		if ( $defaults[ 'meta_color' ] != $options['meta_color'] ) {
			$adventurous_inline_css	.=  ".entry-meta { color: ".  $options['meta_color'] ."; }". "\n";
		}
		if ( $defaults[ 'link_color' ] != $options['link_color'] ) {
			$adventurous_inline_css	.=  "a, a:hover { color: ".  $options['link_color'] ."; }". "\n";
		}
		if ( $defaults[ 'scrollup_bg_color' ] != $options['scrollup_bg_color'] || $defaults[ 'scrollup_text_color' ] != $options['scrollup_text_color'] ) {
			$adventurous_inline_css	.=  "a#scrollup { background-color: ".  $options['scrollup_bg_color'] ."; color: ".  $options['scrollup_text_color'] ."; }". "\n";
		}

		//Promotion Color Options
		if ( $defaults[ 'promotion_background' ] != $options['promotion_background'] ) {
			$adventurous_inline_css	.= "#homepage-message { background-color: ".  $options['promotion_background'] ."; }". "\n";
		}
		if ( $defaults[ 'home_headline' ] != $options['home_headline'] ) {
			$adventurous_inline_css	.=  "#homepage-message { color: ".  $options['home_headline'] ."; }". "\n";
		}
		if ( $defaults[ 'promotion_button_background' ] != $options['promotion_button_background'] || $defaults[ 'promotion_button_border_color' ] != $options['promotion_button_border_color'] || $defaults[ 'promotion_button_text_color' ] != $options['promotion_button_text_color'] ) {
			$adventurous_inline_css	.=  "#homepage-message .right-section a { background-color: ".  $options['promotion_button_background'] ."; border-color: ".  $options['promotion_button_border_color'] ."; color: ".  $options['promotion_button_text_color'] ."; }". "\n";
		}
		if ( $defaults[ 'promotion_button_background' ] != $options['promotion_button_background'] ) {
			$adventurous_inline_css	.= "#homepage-message .right-section a:hover { background-color: ".  $options['promotion_button_background'] ."; }". "\n";
		}

		//Sidebar Color Options
		if ( $defaults[ 'sidebar_background' ] != $options['sidebar_background'] ) {
			$adventurous_inline_css	.= "#secondary .widget { background-color: ".  $options['sidebar_background'] ."; }". "\n";
		}
		if ( $defaults[ 'widget_title_color' ] != $options['widget_title_color'] ) {
			$adventurous_inline_css	.=  "#secondary .widget-title, #secondary .widget-title a, #secondary .widget-title a:hover { color: ".  $options['widget_title_color'] ."; }". "\n";
		}
		if ( $defaults[ 'widget_color' ] != $options['widget_color'] ) {
			$adventurous_inline_css	.=  "#secondary.widget-area .widget { color: ".  $options['widget_color'] ."; }". "\n";
		}
		if ( $defaults[ 'widget_link_color' ] != $options['widget_link_color'] ) {
			$adventurous_inline_css	.=  "#secondary.widget-area .widget a, #secondary.widget-area .widget a:hover { color: ".  $options['widget_link_color'] ."; }". "\n";
		}

		//Footer Color Options
		if ( $defaults[ 'footer_sidebar_background' ] != $options['footer_sidebar_background'] ) {
			$adventurous_inline_css	.=  "#footer-sidebar { background-color: ".  $options['footer_sidebar_background'] ."; }". "\n";
		}
		if ( $defaults[ 'footer_widget_title_color' ] != $options['footer_widget_title_color'] ) {
			$adventurous_inline_css	.=  "#supplementary .widget-title, #supplementary .widget-title a, #supplementary .widget-title a:hover { color: ".  $options['footer_widget_title_color'] ."; }". "\n";
		}
		if ( $defaults[ 'footer_widget_color' ] != $options['footer_widget_color'] ) {
			$adventurous_inline_css	.=  "#supplementary .widget-area .widget { color: ".  $options['footer_widget_color'] ."; }". "\n";
		}
		if ( $defaults[ 'footer_widget_link_color' ] != $options['footer_widget_link_color'] ) {
			$adventurous_inline_css	.=  "#supplementary .widget-area .widget a, #supplementary .widget-area a:hover { color: ".  $options['footer_widget_link_color'] ."; }". "\n";
		}
		if ( $defaults[ 'footer_background' ] != $options['footer_background'] || $defaults[ 'footer_text_color' ] != $options['footer_text_color'] ) {
			$adventurous_inline_css	.=  "#site-generator { background-color: ".  $options['footer_background'] ."; color: ".  $options['footer_text_color'] ."; }". "\n";
		}
		if ( $defaults[ 'footer_link_color' ] != $options['footer_link_color'] ) {
			$adventurous_inline_css	.=  "#site-generator a, #site-generator a:hover { color: ".  $options['footer_link_color'] ."; }". "\n";
		}

		//Menu Color Options
			// Header Right Menu Color
			if ( ( $defaults[ 'menu_color' ] != $options['menu_color'] ) || ( $defaults[ 'hover_active_text_color' ] != $options['hover_active_text_color'] ) || ( $defaults[ 'sub_menu_border_color' ] != $options['sub_menu_border_color'] ) || ( $defaults[ 'sub_menu_bg_color' ] != $options['sub_menu_bg_color'] ) || ( $defaults[ 'sub_menu_text_color' ] != $options['sub_menu_text_color'] ) || ( $defaults[ 'hover_active_color' ] != $options['hover_active_color'] ) || ( $defaults[ 'sub_menu_hover_color' ] != $options['sub_menu_hover_color'] ) ) {
				// Header Right Menu
				$adventurous_inline_css	.=  "#header-right .widget ul.menu a { color: ".  $options['menu_color'] ."; }". "\n";
				$adventurous_inline_css	.=  "#header-right .widget ul.menu li:hover > a, #header-right .widget ul.menu a:focus, #header-right .widget ul.menu .current-menu-item > a, #header-right .widget ul.menu .current-menu-ancestor > a, #header-right .widget ul.menu .current_page_item > a, #header-right .widget ul.menu .current_page_ancestor > a { color: ".  $options['hover_active_text_color'] ."; }". "\n";
				// Heaer Right Sub-menu Border Top Color
				$adventurous_inline_css	.=  "#header-right .widget ul.menu ul { border-color: ".  $options['sub_menu_border_color'] ."; }". "\n";
				// Header Right Sub-Menu
				$adventurous_inline_css	.=  "#header-right .widget ul.menu ul { background-color: ".  $options['sub_menu_bg_color'] ."; }". "\n";
				$adventurous_inline_css	.=  "#header-right .widget ul.menu ul li a { color: ".  $options['sub_menu_text_color'] ."; }". "\n";
				$adventurous_inline_css	.=  "#header-right .widget ul.menu ul li:hover > a, #header-right .widget ul.menu ul a:focus, #header-right .widget ul.menu ul .current-menu-item > a, #header-right .widget ul.menu ul .current-menu-ancestor > a, #header-right .widget ul.menu ul .current_page_item > a, #header-right .widget ul.menu ul .current_page_ancestor > a { background-color: ".  $options['hover_active_color'] ."; }". "\n";
				$adventurous_inline_css	.=  "#header-right .widget ul.menu ul li:hover > a, #header-right .widget ul.menu ul a:focus, #header-right .widget ul.menu ul .current-menu-item > a, #header-right .widget ul.menu ul .current-menu-ancestor > a, #header-right .widget ul.menu ul .current_page_item > a, #header-right .widget ul.menu ul .current_page_ancestor > a { color: ".  $options['sub_menu_hover_color'] ."; }". "\n";
			}

			// Header Menu Color
			if ( ( $defaults[ 'secondary_menu_background' ] != $options['secondary_menu_background'] ) || ( $defaults[ 'secondary_menu_color' ] != $options['secondary_menu_color'] ) || ( $defaults[ 'secondary_hover_active_color' ] != $options['secondary_hover_active_color'] ) || ( $defaults[ 'secondary_hover_active_text_color' ] != $options['secondary_hover_active_text_color'] ) || ( $defaults[ 'secondary_sub_menu_bg_color' ] != $options['secondary_sub_menu_bg_color'] ) || ( $defaults[ 'secondary_sub_menu_text_color' ] != $options['secondary_sub_menu_text_color'] ) ) {
				$adventurous_inline_css	.=  "#secondary-menu { background-color: ".  $options['secondary_menu_background'] ."; }". "\n";
				$adventurous_inline_css	.=  "#secondary-menu ul.menu a { color: ".  $options['secondary_menu_color'] ."; }". "\n";
				$adventurous_inline_css	.=  "#secondary-menu ul.menu li:hover > a, #secondary-menu ul.menu a:focus, #secondary-menu .menu .current-menu-item > a, #secondary-menu .menu .current-menu-ancestor > a, #secondary-menu .menu .current_page_item > a, #secondary-menu .menu .current_page_ancestor > a { background-color: ".  $options['secondary_hover_active_color'] ."; color: ".  $options['secondary_hover_active_text_color'] ."; }". "\n";
				$adventurous_inline_css	.=  "#secondary-menu ul.menu ul a { background-color: ".  $options['secondary_sub_menu_bg_color'] ."; color: ".  $options['secondary_sub_menu_text_color'] ."; }". "\n";
				$adventurous_inline_css	.=  "#secondary-menu ul.menu ul li:hover > a, #secondary-menu ul.menu ul a:focus, #secondary-menu ul.menu ul .current-menu-item > a, #secondary-menu ul.menu ul .current-menu-ancestor > a, #secondary-menu ul.menu ul .current_page_item > a, #secondary-menu  ul.menu ul .current_page_ancestor > a { background-color: ".  $options['secondary_sub_menu_hoverbg_color'] ."; color: ".  $options['secondary_sub_menu_hovertext_color'] ."; }". "\n";
			}

			// Footer Menu Color
			if ( ( $defaults[ 'footer_menu_background' ] != $options['footer_menu_background'] ) || ( $defaults[ 'footer_menu_color' ] != $options['footer_menu_color'] ) || ( $defaults[ 'footer_hover_active_color' ] != $options['footer_hover_active_color'] ) || ( $defaults[ 'footer_hover_active_text_color' ] != $options['footer_hover_active_text_color'] ) || ( $defaults[ 'footer_sub_menu_bg_color' ] != $options['footer_sub_menu_bg_color'] ) || ( $defaults[ 'footer_sub_menu_text_color' ] != $options['footer_sub_menu_text_color'] ) || ( $defaults[ 'footer_sub_menu_hoverbg_color' ] != $options['footer_sub_menu_hoverbg_color'] ) || ( $defaults[ 'footer_sub_menu_hovertext_color' ] != $options['footer_sub_menu_hovertext_color'] ) ) {
				$adventurous_inline_css	.=  "#footer-menu { background-color: ".  $options['footer_menu_background'] ."; }". "\n";
				$adventurous_inline_css	.=  "#footer-menu ul.menu a { color: ".  $options['footer_menu_color'] ."; }". "\n";
				$adventurous_inline_css	.=  "#footer-menu ul.menu li:hover > a, #footer-menu ul.menu a:focus, #footer-menu .menu .current-menu-item > a, #footer-menu .menu .current-menu-ancestor > a, #footer-menu .menu .current_page_item > a, #footer-menu .menu .current_page_ancestor > a { background-color: ".  $options['footer_hover_active_color'] ."; color: ".  $options['footer_hover_active_text_color'] ."; }". "\n";
				$adventurous_inline_css	.=  "#footer-menu ul.menu ul a { background-color: ".  $options['footer_sub_menu_bg_color'] ."; color: ".  $options['footer_sub_menu_text_color'] ."; }". "\n";
				$adventurous_inline_css	.=  "#footer-menu ul.menu ul li:hover > a, #footer-menu ul.menu ul a:focus, #footer-menu ul.menu ul .current-menu-item > a, #footer-menu ul.menu ul .current-menu-ancestor > a, #footer-menu ul.menu ul .current_page_item > a, #footer-menu  ul.menu ul .current_page_ancestor > a { background-color: ".  $options['footer_sub_menu_hoverbg_color'] ."; color: ".  $options['footer_sub_menu_hovertext_color'] ."; }". "\n";
			}

			// Mobile Menu Color
			if ( ( $defaults[ 'mobile_menu_hamburger' ] != $options['mobile_menu_hamburger'] ) || ( $defaults[ 'mobile_menu_hamburger_hover' ] != $options['mobile_menu_hamburger_hover'] ) || ( $defaults[ 'mobile_menu_bg_color' ] != $options['mobile_menu_bg_color'] ) || ( $defaults[ 'mobile_menu_text_color' ] != $options['mobile_menu_text_color'] ) || ( $defaults[ 'mobile_menu_border_top' ] != $options['mobile_menu_border_top'] ) || ( $defaults[ 'mobile_menu_border' ] != $options['mobile_menu_border'] ) || ( $defaults[ 'mobile_menu_hover_bg_color' ] != $options['mobile_menu_hover_bg_color'] ) || ( $defaults[ 'mobile_menu_hover_text_color' ] != $options['mobile_menu_hover_text_color'] ) ) {
			$adventurous_inline_css	.=  "@media screen and (max-width: 980px) {". "\n";
				$adventurous_inline_css	.=  "#hgroup-wrap .mobile-menu-bar { color: ".  $options['mobile_menu_hamburger'] ."; }". "\n";
				$adventurous_inline_css	.=  "#hgroup-wrap .mobile-menu-bar:hover { color: ".  $options['mobile_menu_hamburger_hover'] ."; }". "\n";
				$adventurous_inline_css	.=  "#hgroup-wrap .mobile-menu { background-color: ".  $options['mobile_menu_bg_color'] ."; border-color: ".  $options['mobile_menu_border_top'] ."; }". "\n";
				$adventurous_inline_css	.=  "#hgroup-wrap .mobile-menu li a { border-color: ".  $options['mobile_menu_border'] ."; color: ".  $options['mobile_menu_text_color'] ."; }". "\n";
				$adventurous_inline_css	.=  "#hgroup-wrap .mobile-menu li a:hover { background-color: ".  $options['mobile_menu_hover_bg_color'] ."; color: ".  $options['mobile_menu_hover_text_color'] ."; }". "\n";
			$adventurous_inline_css	.=  "}". "\n";
			}

		// Typography (Font Family) Options
		if ( $defaults[ 'body_font' ] != $options['body_font'] ) {
			$adventurous_inline_css	.=  "body, button, input, select, textarea { font-family: ". $fonts [ $options['body_font'] ] ."; }". "\n";
		}
		if ( $defaults[ 'title_font' ] != $options['title_font'] ) {
			$adventurous_inline_css	.=  "#site-title { font-family: ". $fonts [ $options['title_font'] ] ."; }". "\n";
		}
		if ( $defaults[ 'tagline_font' ] != $options['tagline_font'] ) {
			$adventurous_inline_css	.=  "#site-description { font-family: ". $fonts [ $options['tagline_font'] ] ."; }". "\n";
		}
		if ( $defaults[ 'content_tittle_font' ] != $options['content_tittle_font'] ) {
			$adventurous_inline_css	.=  "#primary .entry-header .entry-title, #primary .page-header .page-title { font-family: ". $fonts [ $options['content_tittle_font'] ] ."; }". "\n";
		}
		if ( $defaults[ 'content_font' ] != $options['content_font'] ) {
			$adventurous_inline_css	.=  "#primary .hentry { font-family: ". $fonts [ $options['content_font'] ] ."; }". "\n";
		}
		if ( $defaults[ 'headings_font' ] != $options['headings_font'] ) {
			$adventurous_inline_css	.=  "h1, h2, h3, h4, h5, h6 { font-family: ". $fonts [ $options['headings_font'] ] ."; }". "\n";
		}

		//Custom CSS Option
		if ( !empty( $options['custom_css'] ) ) {

			$adventurous_inline_css .=  $options['custom_css'] . "\n";

		}

		if ( '' != $adventurous_inline_css ){
			echo '<!-- refreshing custom css cache -->' . "\n";

			$adventurous_inline_css = '
				<!-- '.get_bloginfo('name').' inline CSS Styles -->' . "\n" . '
					<style type="text/css" media="screen">' . "\n" .
						$adventurous_inline_css . '
					</style>' . "\n";
		}

	set_transient( 'adventurous_inline_css', $adventurous_inline_css, 86940 );
	}
	echo $adventurous_inline_css;
}
add_action('wp_head', 'adventurous_inline_css');


/**
 * Sets the post excerpt length to 30 words.
 *
 * function tied to the excerpt_length filter hook.
 * @uses filter excerpt_length
 */
function adventurous_excerpt_length( $length ) {
	// Getting data from Theme Options
	$options = adventurous_get_options();

	return $options['excerpt_length'];
}
add_filter( 'excerpt_length', 'adventurous_excerpt_length' );


/**
 * Returns a "Continue Reading" link for excerpts
 */
function adventurous_continue_reading() {
	// Getting data from Theme Options
	$options = adventurous_get_options();

	$more_tag_text = $options['more_tag_text'];
	return ' <a class="more-link" href="'. esc_url( get_permalink() ) . '">' .  $more_tag_text . '</a>';
}

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with adventurous_continue_reading().
 *
 */
function adventurous_excerpt_more( $more ) {
	return adventurous_continue_reading();
}
add_filter( 'excerpt_more', 'adventurous_excerpt_more' );


/**
 * Adds Continue Reading link to post excerpts.
 *
 * function tied to the get_the_excerpt filter hook.
 */
function adventurous_custom_excerpt( $output ) {
	if ( has_excerpt() && ! is_attachment() ) {
		$output .= adventurous_continue_reading();
	}
	return $output;
}
add_filter( 'get_the_excerpt', 'adventurous_custom_excerpt' );


/**
 * Replacing Continue Reading link to the_content more.
 *
 * function tied to the the_content_more_link filter hook.
 */
function adventurous_more_link( $more_link, $more_link_text ) {
	// Getting data from Theme Options
	$options = adventurous_get_options();

	$more_tag_text = $options['more_tag_text'];

	return str_replace( $more_link_text, $more_tag_text, $more_link );
}
add_filter( 'the_content_more_link', 'adventurous_more_link', 10, 2 );


/**
 * Redirect WordPress Feeds To FeedBurner
 */
function adventurous_rss_redirect() {
	// Getting data from Theme Options
	$options = adventurous_get_options();

    if ($options['feed_url']) {
		$url = 'Location: '.$options['feed_url'];
		if ( is_feed() && !preg_match('/feedburner|feedvalidator/i', $_SERVER['HTTP_USER_AGENT']))
		{
			header($url);
			header('HTTP/1.1 302 Temporary Redirect');
		}
	}
}
add_action('template_redirect', 'adventurous_rss_redirect');


/**
 * Adds custom classes to the array of body classes.
 *
 * @since Adventurous 1.0
 */
function adventurous_body_classes( $classes ) {
	//Getting Ready to load data from Theme Options Panel
	$options  = adventurous_get_options();

	if ( ( class_exists( 'Woocommerce' ) && is_woocommerce() ) &&  !is_active_sidebar( 'adventurous_woocommerce_sidebar' ) ) {
		$classes[] = 'woocommerce-nosidebar';
	}

	if ( is_page_template( 'template-blog.php') ) {
		$classes[] = 'page-blog';
	}

	// Adds a class of group-blog to blogs with more than 1 published author
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	$classes[] = adventurous_get_theme_layout();

	$current_content_layout = $options['content_layout'];
	if ( 'full' == $current_content_layout ) {
		$classes[] = 'content-full';
	}
	elseif ( 'excerpt' == $current_content_layout ) {
		$classes[] = 'content-excerpt';
	}

	return $classes;
}
add_filter( 'body_class', 'adventurous_body_classes' );


/**
 * Filter in a link to a content ID attribute for the next/previous image links on image attachment pages
 *
 * @since Adventurous 1.0
 */
function adventurous_enhanced_image_navigation( $url, $id ) {
	if ( ! is_attachment() && ! wp_attachment_is_image( $id ) )
		return $url;

	$image = get_post( $id );
	if ( ! empty( $image->post_parent ) && $image->post_parent != $id )
		$url .= '#main';

	return $url;
}
add_filter( 'attachment_link', 'adventurous_enhanced_image_navigation', 10, 2 );


/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 *
 * @since Adventurous 1.0
 */
function adventurous_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'adventurous_page_menu_args' );


/**
 * Removes div from wp_page_menu() and replace with ul.
 *
 * @since Adventurous 1.0
 */
function adventurous_wp_page_menu ($page_markup) {
    preg_match('/^<div class=\"([a-z0-9-_]+)\">/i', $page_markup, $matches);
        $divclass = $matches[1];
        $replace = array('<div class="'.$divclass.'">', '</div>');
        $new_markup = str_replace($replace, '', $page_markup);
        $new_markup = preg_replace('/^<ul>/i', '<ul class="'.$divclass.'">', $new_markup);
        return $new_markup; }

add_filter( 'wp_page_menu', 'adventurous_wp_page_menu' );


if ( ! function_exists( 'adventurous_main_wrapper' ) ) :
/**
 * Open Div ID main
 *
 */
function adventurous_main_wrapper() {
	echo '<div id="main">';
}
endif; // adventurous_main_wrapper


if ( ! function_exists( 'adventurous_main_wrapper_close' ) ) :
/**
 * Close Div ID main
 *
 */
function adventurous_main_wrapper_close() {
	echo '</div><!-- #main -->';
}
endif; // adventurous_main_wrapper_close



if ( ! function_exists( 'adventurous_content_sidebar_wrapper' ) ) :
/**
 * Open Div ID content-sidebar
 *
 */
function adventurous_content_sidebar_wrapper() {
	echo '<div id="content-sidebar" class="container">';
}
endif; // adventurous_content_sidebar_wrapper


if ( ! function_exists( 'adventurous_content_sidebar_wrapper_close' ) ) :
/**
 * Close Div ID content-sidebar
 *
 */
function adventurous_content_sidebar_wrapper_close() {
	echo '</div><!-- #content-sidebar -->';
}
endif; // adventurous_content_sidebar_wrapper_close


if ( ! function_exists( 'content_sidebar_check' ) ) :
/**
 * Cheking in Condition for main Wrap
 *
 */
function content_sidebar_check() {
	global $post, $wp_query;
	$options = adventurous_get_options();
	$enable_post = $options['enable_posts_home'];

	// Front page displays in Reading Settings
	$page_on_front = get_option('page_on_front') ;
	$page_for_posts = get_option('page_for_posts');

	// Get Page ID outside Loop
	$page_id = $wp_query->get_queried_object_id();

	if ( is_front_page() && is_home() && !empty( $enable_post ) ) {
		return;
	}
	elseif ( is_front_page() ) {
		add_action( 'adventurous_main', 'adventurous_main_wrapper', 10 );
		add_action( 'adventurous_content_sidebar', 'adventurous_content_sidebar_wrapper', 10 );
		add_action( 'adventurous_content_sidebar_close', 'adventurous_content_sidebar_wrapper_close', 10 );
		add_action( 'adventurous_main_close', 'adventurous_main_wrapper_close', 10 );
	}
	elseif ( is_home() && !empty( $enable_post ) && empty( $page_id ) ) {
		return;
	}
	else {
		add_action( 'adventurous_main', 'adventurous_main_wrapper', 10 );
		add_action( 'adventurous_content_sidebar', 'adventurous_content_sidebar_wrapper', 10 );
		add_action( 'adventurous_content_sidebar_close', 'adventurous_content_sidebar_wrapper_close', 10 );
		add_action( 'adventurous_main_close', 'adventurous_main_wrapper_close', 10 );
	}
}
endif; // content_sidebar_check

add_action( 'adventurous_before_main', 'content_sidebar_check', 20 );

/**
 * Third Sidebar
 *
 * @Hooked in adventurous_content_sidebar_end
 * @since Adventurous 1.0
 */
function adventurous_third_sidebar() {
	get_sidebar( 'third' );
}
add_action( 'adventurous_content_sidebar_close', 'adventurous_third_sidebar', 15 );


/**
 * Footer Sidebar
 *
 * @Hooked in adventurous_footer
 * @since Adventurous 1.0
 */
function adventurous_footer_sidebar() {
	get_sidebar( 'footer' );
}
add_action( 'adventurous_footer', 'adventurous_footer_sidebar', 20 );


/**
 * Count the number of footer sidebars to enable dynamic classes for the footer
 */
function adventurous_footer_sidebar_class() {
	$count = 0;

	if ( is_active_sidebar( 'sidebar-2' ) )
		$count++;

	if ( is_active_sidebar( 'sidebar-3' ) )
		$count++;

	if ( is_active_sidebar( 'sidebar-4' ) )
		$count++;

	if ( is_active_sidebar( 'sidebar-5' ) )
		$count++;

	$class = '';

	switch ( $count ) {
		case '1':
			$class = 'one container';
			break;
		case '2':
			$class = 'two container';
			break;
		case '3':
			$class = 'three container';
			break;
		case '4':
			$class = 'four container';
			break;
	}

	if ( $class )
		echo 'class="' . $class . '"';
}


/**
 * Footer Site Generator Open
 *
 * @Hooked in adventurous_site_generator
 * @since Adventurous 1.0
 */
function adventurous_site_generator_open() {
	echo '<div id="site-generator"><div class="site-info container">';
}
add_action( 'adventurous_site_generator', 'adventurous_site_generator_open', 10 );


/**
 * Footer Site Generator Close
 *
 * @Hooked in adventurous_site_generator
 * @since Adventurous 1.0
 */
function adventurous_site_generator_close() {
	echo '</div><!-- .site-info container --></div><!-- #site-generator -->';
}
add_action( 'adventurous_site_generator', 'adventurous_site_generator_close', 100 );


if ( ! function_exists( 'adventurous_footer_content' ) ) :
/**
 * Template for Footer Content
 *
 * To override this in a child theme
 * simply create your own adventurous_footer_content(), and that function will be used instead.
 *
 * @uses adventurous_site_generator action to add it in the footer
 * @since Adventurous 1.0
 */
function adventurous_footer_content() {
	//delete_transient( 'adventurous_footer_content' );

	if ( ( !$adventurous_footer_content = get_transient( 'adventurous_footer_content' ) ) ) {
		echo '<!-- refreshing cache -->';

		// get the data value from theme options
		$options  = adventurous_get_options();

   	 	$search = array( '[the-year]', '[site-link]', '[wp-link]', '[privacy-policy-link]', '[theme-link]' );

        $replace = array( adventurous_the_year(), adventurous_site_link(), adventurous_wp_link(), get_the_privacy_policy_link(), adventurous_theme_link() );

        $options['footer_code'] = str_replace( $search, $replace, $options['footer_code'] );

        $adventurous_footer_content = $options['footer_code'];

       // $adventurous_footer_content = $options['footer_code'];
		$adventurous_footer_content = $options['footer_code'];

    	set_transient( 'adventurous_footer_content', $adventurous_footer_content, 86940 );
    }
	echo do_shortcode( $adventurous_footer_content );
}
endif;
add_action( 'adventurous_site_generator', 'adventurous_footer_content', 20 );


/**
 * Alter the query for the main loop in homepage
 * @uses pre_get_posts hook
 */
function adventurous_alter_home( $query ){
	if ( $query->is_main_query() && $query->is_home() ) {
		$options  = adventurous_get_options();

	    if ( is_array( $options['front_page_category'] ) && !in_array( '0', $options['front_page_category'] ) ) {
	    	$cats = (array) $options['front_page_category'];
	    	if ( defined( "ICL_LANGUAGE_CODE" ) ) {
			    $category = array();
			    foreach( $cats as $cat ){
			    	$category[] = apply_filters( 'wpml_object_id', $cat, 'category', true );
			    }
			    $cats = $category;
			}
	    }
	    else{
	    	$cats = '0';
	    }

	    if ( '0' != $options[ 'exclude_slider_post'] && !empty( $options['featured_slider'] ) ) {
			$query->query_vars['post__not_in'] = $options['featured_slider'];
		}

		if ( is_array( $cats ) && !in_array( '0', $cats ) ) {
			$query->query_vars['category__in'] = $cats;
		}
	}
}
add_action( 'pre_get_posts','adventurous_alter_home' );


if ( ! function_exists( 'adventurous_social_networks' ) ) :
/**
 * Template for Social Icons
 *
 * To override this in a child theme
 * simply create your own adventurous_social_networks(), and that function will be used instead.
 *
 * @since Adventurous 1.0
 */
function adventurous_social_networks() {
	//delete_transient( 'adventurous_social_networks' );

	// get the data value from theme options
	$options = adventurous_get_options();
	$quantity = $options['social_custom_qty'];

	$adventurous_custom_social_networks = '';

	for ( $i = 1; $i <= $quantity; $i++ ) {
		if ( !empty ( $options['social_custom_image'][ $i ] ) ) {


			$image = esc_url( $options['social_custom_image'][ $i ] );

			if ( isset( $options['social_custom_image_hover'][ $i ] ) && '' != $options['social_custom_image_hover'][ $i ] ) {
				$image_hover = esc_url( $options['social_custom_image_hover'][ $i ] );
			}
			else {
				$image_hover = '';
			}

			//Checking Link
			if ( !empty ( $options['social_custom_url'][ $i ] ) ) {
				$link = esc_url( $options['social_custom_url'][ $i ] );
			} else {
				$link = '#';
			}

			//Checking Title
			if ( !empty ( $options['social_custom_name'][ $i ] ) ) {
				$title = $options['social_custom_name'][ $i ];
			} else {
				$title = 'Social Icons';
			}

			//Custom Social Icons
			$adventurous_custom_social_networks .= '
			<li class="custom-social custom-social-' . $i . '">
				<a href="' . esc_url( $link ) . '" title="' . esc_attr( $title ) . '" target="_blank">
					<img class="icon-static" src="' . $image . '" alt="'.sprintf( esc_attr__( '%1$s on %2$s', 'adventurous-pro' ), get_bloginfo( 'name' ), $title ). '" />';

			if ( '' != $image_hover ) {
				$adventurous_custom_social_networks .= '
					<img class="icon-hover" src="' . $image_hover . '" alt="'.sprintf( esc_attr__( '%1$s on %2$s', 'adventurous-pro' ), get_bloginfo( 'name' ), $title ). '" />';
			}

			$adventurous_custom_social_networks .= '
				</a>
			</li>';
		}
	}

    $elements = array();

	$elements = array( 	$options['social_facebook'],
						$options['social_twitter'],
						$options['social_googleplus'],
						$options['social_linkedin'],
						$options['social_pinterest'],
						$options['social_youtube'],
						$options['social_vimeo'],
						$options['social_slideshare'],
						$options['social_foursquare'],
						$options['social_flickr'],
						$options['social_tumblr'],
						$options['social_deviantart'],
						$options['social_dribbble'],
						$options['social_myspace'],
						$options['social_wordpress'],
						$options['social_rss'],
						$options['social_delicious'],
						$options['social_lastfm'],
						$options['social_instagram'],
						$options['social_github'],
						$options['social_vkontakte'],
						$options['social_myworld'],
						$options['social_odnoklassniki'],
						$options['social_goodreads'],
						$options['social_skype'],
						$options['social_soundcloud'],
						$options['social_email'],
						$options['social_contact'],
						$options['social_xing'],
						$options['social_meetup']

					);
	$flag = 0;
	if ( !empty( $elements ) ) {
		foreach( $elements as $option) {
			if ( !empty( $option ) ) {
				$flag = 1;
			}
			else {
				$flag = 0;
			}
			if ( $flag == 1 ) {
				break;
			}
		}
	}

	if ( ( !$adventurous_social_networks = get_transient( 'adventurous_social_networks' ) ) && ( $flag == 1 || !empty ( $options['social_custom_image'] ) ) )  {
		echo '<!-- refreshing cache -->';

		$adventurous_social_networks .='
		<ul class="social-profile">';

			//facebook
			if ( !empty( $options['social_facebook'] ) ) {
				$adventurous_social_networks .=
					'<li class="facebook"><a href="'.esc_url( $options['social_facebook'] ).'" title="'. esc_attr__( 'Facebook', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'Facebook', 'adventurous-pro' ) .'</a></li>';
			}
			//Twitter
			if ( !empty( $options['social_twitter'] ) ) {
				$adventurous_social_networks .=
					'<li class="twitter"><a href="'.esc_url( $options['social_twitter'] ).'" title="'. esc_attr__( 'Twitter', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'Twitter', 'adventurous-pro' ) .'</a></li>';
			}
			//Google+
			if ( !empty( $options['social_googleplus'] ) ) {
				$adventurous_social_networks .=
					'<li class="google-plus"><a href="'.esc_url( $options['social_googleplus'] ).'" title="'. esc_attr__( 'Google+', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'Google+', 'adventurous-pro' ) .'</a></li>';
			}
			//Linkedin
			if ( !empty( $options['social_linkedin'] ) ) {
				$adventurous_social_networks .=
					'<li class="linkedin"><a href="'.esc_url( $options['social_linkedin'] ).'" title="'. esc_attr__( 'LinkedIn', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'LinkedIn', 'adventurous-pro' ) .'</a></li>';
			}
			//Pinterest
			if ( !empty( $options['social_pinterest'] ) ) {
				$adventurous_social_networks .=
					'<li class="pinterest"><a href="'.esc_url( $options['social_pinterest'] ).'" title="'. esc_attr__( 'Pinterest', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'Pinterest', 'adventurous-pro' ) .'</a></li>';
			}
			//Youtube
			if ( !empty( $options['social_youtube'] ) ) {
				$adventurous_social_networks .=
					'<li class="you-tube"><a href="'.esc_url( $options['social_youtube'] ).'" title="'. esc_attr__( 'YouTube', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'YouTube', 'adventurous-pro' ) .'</a></li>';
			}
			//Vimeo
			if ( !empty( $options['social_vimeo'] ) ) {
				$adventurous_social_networks .=
					'<li class="viemo"><a href="'.esc_url( $options['social_vimeo'] ).'" title="'. esc_attr__( 'Vimeo', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'Vimeo', 'adventurous-pro' ) .'</a></li>';
			}
			//Slideshare
			if ( !empty( $options['social_slideshare'] ) ) {
				$adventurous_social_networks .=
					'<li class="slideshare"><a href="'.esc_url( $options['social_slideshare'] ).'" title="'. esc_attr__( 'SlideShare', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'SlideShare', 'adventurous-pro' ) .'</a></li>';
			}
			//Foursquare
			if ( !empty( $options['social_foursquare'] ) ) {
				$adventurous_social_networks .=
					'<li class="foursquare"><a href="'.esc_url( $options['social_foursquare'] ).'" title="'. esc_attr__( 'FourSquare', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'FourSquare', 'adventurous-pro' ) .'</a></li>';
			}
			//Flickr
			if ( !empty( $options['social_flickr'] ) ) {
				$adventurous_social_networks .=
					'<li class="flickr"><a href="'.esc_url( $options['social_flickr'] ).'" title="'. esc_attr__( 'Flickr', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'Flickr', 'adventurous-pro' ) .'</a></li>';
			}
			//Tumblr
			if ( !empty( $options['social_tumblr'] ) ) {
				$adventurous_social_networks .=
					'<li class="tumblr"><a href="'.esc_url( $options['social_tumblr'] ).'" title="'. esc_attr__( 'Tumblr', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'Tumblr', 'adventurous-pro' ) .'</a></li>';
			}
			//deviantART
			if ( !empty( $options['social_deviantart'] ) ) {
				$adventurous_social_networks .=
					'<li class="deviantart"><a href="'.esc_url( $options['social_deviantart'] ).'" title="'. esc_attr__( 'deviantART', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'deviantART', 'adventurous-pro' ) .'</a></li>';
			}
			//Dribbble
			if ( !empty( $options['social_dribbble'] ) ) {
				$adventurous_social_networks .=
					'<li class="dribbble"><a href="'.esc_url( $options['social_dribbble'] ).'" title="'. esc_attr__( 'Dribbble', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'Dribbble', 'adventurous-pro' ) .'</a></li>';
			}
			//MySpace
			if ( !empty( $options['social_myspace'] ) ) {
				$adventurous_social_networks .=
					'<li class="myspace"><a href="'.esc_url( $options['social_myspace'] ).'" title="'. esc_attr__( 'MySpace', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'MySpace', 'adventurous-pro' ) .'</a></li>';
			}
			//WordPress
			if ( !empty( $options['social_wordpress'] ) ) {
				$adventurous_social_networks .=
					'<li class="wordpress"><a href="'.esc_url( $options['social_wordpress'] ).'" title="'. esc_attr__( 'WordPress', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'WordPress', 'adventurous-pro' ) .'</a></li>';
			}
			//RSS
			if ( !empty( $options['social_rss'] ) ) {
				$adventurous_social_networks .=
					'<li class="rss"><a href="'.esc_url( $options['social_rss'] ).'" title="'. esc_attr__( 'RSS', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'RSS', 'adventurous-pro' ) .'</a></li>';
			}
			//Delicious
			if ( !empty( $options['social_delicious'] ) ) {
				$adventurous_social_networks .=
					'<li class="delicious"><a href="'.esc_url( $options['social_delicious'] ).'" title="'. esc_attr__( 'Delicious', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'Delicious', 'adventurous-pro' ) .'</a></li>';
			}
			//Last.fm
			if ( !empty( $options['social_lastfm'] ) ) {
				$adventurous_social_networks .=
					'<li class="lastfm"><a href="'.esc_url( $options['social_lastfm'] ).'" title="'. esc_attr__( 'Last.fm', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'Last.fm', 'adventurous-pro' ) .'</a></li>';
			}
			//Instagram
			if ( !empty( $options['social_instagram'] ) ) {
				$adventurous_social_networks .=
					'<li class="instagram"><a href="'.esc_url( $options['social_instagram'] ).'" title="'. esc_attr__( 'Instagram', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'Instagram', 'adventurous-pro' ) .'</a></li>';
			}
			//GitHub
			if ( !empty( $options['social_github'] ) ) {
				$adventurous_social_networks .=
					'<li class="github"><a href="'.esc_url( $options['social_github'] ).'" title="'. esc_attr__( 'GitHub', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'GitHub', 'adventurous-pro' ) .'</a></li>';
			}
			//Vkontakte
			if ( !empty( $options['social_vkontakte'] ) ) {
				$adventurous_social_networks .=
					'<li class="vkontakte"><a href="'.esc_url( $options['social_vkontakte'] ).'" title="'. esc_attr__( 'Vkontakte', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'Vkontakte', 'adventurous-pro' ) .'</a></li>';
			}
			//My World
			if ( !empty( $options['social_myworld'] ) ) {
				$adventurous_social_networks .=
					'<li class="myworld"><a href="'.esc_url( $options['social_myworld'] ).'" title="'. esc_attr__( 'My World', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'My World', 'adventurous-pro' ) .'</a></li>';
			}
			//Odnoklassniki
			if ( !empty( $options['social_odnoklassniki'] ) ) {
				$adventurous_social_networks .=
					'<li class="odnoklassniki"><a href="'.esc_url( $options['social_odnoklassniki'] ).'" title="'. esc_attr__( 'Odnoklassniki', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'Odnoklassniki', 'adventurous-pro' ) .'</a></li>';
			}
			//Goodreads
			if ( !empty( $options['social_goodreads'] ) ) {
				$adventurous_social_networks .=
					'<li class="goodreads"><a href="'.esc_url( $options['social_goodreads'] ).'" title="'. esc_attr__( 'GoodReads', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'GoodReads', 'adventurous-pro' ) .'</a></li>';
			}
			//Skype
			if ( !empty( $options['social_skype'] ) ) {
				$adventurous_social_networks .=
					'<li class="skype"><a href="'.esc_attr( $options['social_skype'] ).'" title="'. esc_attr__( 'Skype', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'Skype', 'adventurous-pro' ) .'</a></li>';
			}
			//Soundcloud
			if ( !empty( $options['social_soundcloud'] ) ) {
				$adventurous_social_networks .=
					'<li class="soundcloud"><a href="'.esc_url( $options['social_soundcloud'] ).'" title="'. esc_attr__( 'SoundCloud', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'SoundCloud', 'adventurous-pro' ) .'</a></li>';
			}
			//Email
			if ( !empty( $options['social_email'] ) ) {
				$adventurous_social_networks .=
					'<li class="email"><a href="mailto:'.sanitize_email( $options['social_email'] ).'" title="'. esc_attr__( 'Email', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'Email', 'adventurous-pro' ) .'</a></li>';
			}
			//Contact
			if ( !empty( $options['social_contact'] ) ) {
				$adventurous_social_networks .=
					'<li class="contactus"><a href="'.esc_url( $options['social_contact'] ).'" title="'. esc_attr__( 'Contact', 'adventurous-pro' ) .'">'. esc_attr__( 'Contact', 'adventurous-pro' ) .'</a></li>';
			}
			//Xing
			if ( !empty( $options['social_xing'] ) ) {
				$adventurous_social_networks .=
					'<li class="xing"><a href="'.esc_url( $options['social_xing'] ).'" title="'. esc_attr__( 'Xing', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'Xing', 'adventurous-pro' ) .'</a></li>';
			}
			//Meetup
			if ( !empty( $options['social_meetup'] ) ) {
				$adventurous_social_networks .=
					'<li class="meetup"><a href="'.esc_url( $options['social_meetup'] ).'" title="'. esc_attr__( 'Meetup', 'adventurous-pro' ) .'" target="_blank">'. esc_attr__( 'Meetup', 'adventurous-pro' ) .'</a></li>';
			}

			$adventurous_social_networks .= $adventurous_custom_social_networks;

			$adventurous_social_networks .='
		</ul>';

		set_transient( 'adventurous_social_networks', $adventurous_social_networks, 86940 );
	}
	echo $adventurous_social_networks;
}
endif; // adventurous_social_networks


/**
 * Site Verification and Header Code from the Theme Option
 *
 * If user sets the code we're going to display meta verification
 * @get the data value from theme options
 * @uses wp_head action to add the code in the header
 * @uses set_transient and delete_transient API for cache
 */
function adventurous_webmaster() {
	//delete_transient( 'adventurous_webmaster' );

	if ( ( !$adventurous_webmaster = get_transient( 'adventurous_webmaster' ) ) ) {

		// get the data value from theme options
		$options  = adventurous_get_options();
		echo '<!-- refreshing cache -->';

		$adventurous_webmaster = '';
		//google
		if ( !empty( $options['google_verification'] ) ) {
			$adventurous_webmaster .= '<meta name="google-site-verification" content="' .  $options['google_verification'] . '" />' . "\n";
		}
		//bing
		if ( !empty( $options['bing_verification'] ) ) {
			$adventurous_webmaster .= '<meta name="msvalidate.01" content="' .  $options['bing_verification']  . '" />' . "\n";
		}
		//yahoo
		 if ( !empty( $options['yahoo_verification'] ) ) {
			$adventurous_webmaster .= '<meta name="y_key" content="' .  $options['yahoo_verification']  . '" />' . "\n";
		}
		//site stats, analytics header code
		if ( !empty( $options['analytic_header'] ) ) {
			$adventurous_webmaster =  $options['analytic_header'] ;
		}

		set_transient( 'adventurous_webmaster', $adventurous_webmaster, 86940 );
	}
	echo $adventurous_webmaster;
}
add_action('wp_head', 'adventurous_webmaster');


/**
 * This function loads the Footer Code such as Add this code from the Theme Option
 *
 * @get the data value from theme options
 * @load on the footer ONLY
 * @uses wp_footer action to add the code in the footer
 * @uses set_transient and delete_transient
 */
function adventurous_footercode() {
	//delete_transient( 'adventurous_footercode' );

	if ( ( !$adventurous_footercode = get_transient( 'adventurous_footercode' ) ) ) {

		// get the data value from theme options
		$options  = adventurous_get_options();
		echo '<!-- refreshing cache -->';

		//site stats, analytics header code
		if ( !empty( $options['analytic_footer'] ) ) {
			$adventurous_footercode =  $options['analytic_footer'] ;
		}

		set_transient( 'adventurous_footercode', $adventurous_footercode, 86940 );
	}
	echo $adventurous_footercode;
}
add_action('wp_footer', 'adventurous_footercode');


/**
 * Adds in post and Page ID when viewing lists of posts and pages
 * This will help the admin to add the post ID in featured slider
 *
 * @param mixed $post_columns
 * @return post columns
 */
function adventurous_post_id_column( $post_columns ) {
	$beginning = array_slice( $post_columns, 0 ,1 );
	$beginning[ 'postid' ] = __( 'ID', 'adventurous-pro'  );
	$ending = array_slice( $post_columns, 1 );
	$post_columns = array_merge( $beginning, $ending );
	return $post_columns;
}
add_filter( 'manage_posts_columns', 'adventurous_post_id_column' );
add_filter( 'manage_pages_columns', 'adventurous_post_id_column' );

function adventurous_posts_id_column( $col, $val ) {
	if ( 'postid' == $col ) echo $val;
}
add_action( 'manage_posts_custom_column', 'adventurous_posts_id_column', 10, 2 );
add_action( 'manage_pages_custom_column', 'adventurous_posts_id_column', 10, 2 );

function adventurous_posts_id_column_css() {
	echo '
	<style type="text/css">
	    #postid { width: 80px; }
	    @media screen and (max-width: 782px) {
	        .wp-list-table #postid, .wp-list-table #the-list .postid { display: none; }
	        .wp-list-table #the-list .is-expanded .postid {
	            padding-left: 30px;
	        }
	    }
    </style>';
}
add_action( 'admin_head-edit.php', 'adventurous_posts_id_column_css' );


if ( ! function_exists( 'adventurous_pagemenu_filter' ) ) :
/**
 * @uses wp_page_menu filter hook
 */
function adventurous_pagemenu_filter( $text ) {
	$replace = array(
		'current_page_item'     => 'current-menu-item'
	);

	$text = str_replace( array_keys( $replace ), $replace, $text );
  	return $text;

}
endif; // adventurous_pagemenu_filter
add_filter('wp_page_menu', 'adventurous_pagemenu_filter');


/**
 * Shows Header Top Sidebar
 */
function adventurous_header_top() {

	/* A sidebar in the Header Top
	*/
	get_sidebar( 'header-top' );

}
add_action( 'adventurous_before_header', 'adventurous_header_top', 10 );


if ( ! function_exists( 'adventurous_breadcrumb_display' ) ) :
/**
 * Display breadcrumb on header
 */
function adventurous_breadcrumb_display() {
	global $post, $wp_query;

	// Front page displays in Reading Settings
	$page_on_front = get_option('page_on_front') ;
	$page_for_posts = get_option('page_for_posts');

	// Get Page ID outside Loop
	$page_id = $wp_query->get_queried_object_id();

	if ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) {
		return false;
	}
	else {
		if ( function_exists( 'bcn_display_list' ) ) {
			echo
			'<div class="breadcrumb container">
				<ul>';
					bcn_display_list();
					echo '
				</ul>
				<div class="row-end"></div>
			</div> <!-- .breadcrumb -->';
		}
	}

} // adventurous_breadcrumb_display
endif;

// Load  breadcrumb in adventurous_after_hgroup_wrap hook
add_action( 'adventurous_content_sidebar', 'adventurous_breadcrumb_display', 20 );


/**
 * This function loads Scroll Up Navigation
 *
 * @get the data value from theme options for disable
 * @uses adventurous_after_footer action to add the code in the footer
 * @uses set_transient and delete_transient
 */
function adventurous_scrollup() {
	//delete_transient( 'adventurous_scrollup' );

	if ( !$adventurous_scrollup = get_transient( 'adventurous_scrollup' ) ) {

		// get the data value from theme options
		$options  = adventurous_get_options();
		echo '<!-- refreshing cache -->';

		//site stats, analytics header code
		if ( empty( $options['disable_scrollup'] ) ) {
			$adventurous_scrollup =  '<a href="#masthead" id="scrollup"></a>' ;
		}

		set_transient( 'adventurous_scrollup', $adventurous_scrollup, 86940 );
	}
	echo $adventurous_scrollup;
}
add_action( 'adventurous_after_footer', 'adventurous_scrollup', 10 );
